@@ -86,7 +86,7 @@
 #define THREADWEAVER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef THREADWEAVER_NO_DEPRECATED
-#  define THREADWEAVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54400
+#  define THREADWEAVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55000
 #endif
 #ifdef THREADWEAVER_NO_DEPRECATED_WARNINGS
 #  define THREADWEAVER_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef THREADWEAVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define THREADWEAVER_DEPRECATED_WARNINGS_SINCE THREADWEAVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define THREADWEAVER_DEPRECATED_WARNINGS_SINCE 0x54400
+#    define THREADWEAVER_DEPRECATED_WARNINGS_SINCE 0x55000
 #  endif
 #endif
 
@@ -115,7 +115,14 @@
 #else
 #  define THREADWEAVER_DEPRECATED_VERSION_5_0(text)
 #endif
+
+#if THREADWEAVER_DEPRECATED_WARNINGS_SINCE >= 0x55000
+#  define THREADWEAVER_DEPRECATED_VERSION_5_80(text) THREADWEAVER_DECL_DEPRECATED_TEXT(text)
+#else
+#  define THREADWEAVER_DEPRECATED_VERSION_5_80(text)
+#endif
 #define THREADWEAVER_DEPRECATED_VERSION_5(minor, text)      THREADWEAVER_DEPRECATED_VERSION_5_##minor(text)
 #define THREADWEAVER_DEPRECATED_VERSION(major, minor, text) THREADWEAVER_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define THREADWEAVER_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) THREADWEAVER_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* THREADWEAVER_EXPORT_H */
